/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TimedObjectBean.java 5602 2010-10-01 15:49:31Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.examples.timerservice;

import java.util.Date;

import javax.annotation.Resource;
import javax.ejb.Stateless;
import javax.ejb.TimedObject;
import javax.ejb.Timer;
import javax.ejb.TimerService;

/**
 * Bean that implements the TimedObject interface. <br/>
 * The timeout method will be ejbTimeout().
 * @author Florent Benoit
 */
@Stateless
public class TimedObjectBean implements TimedObject, TimedLocal {

    /**
     * Time before firing a new Timer.
     */
    private static final long FIRING_TIME = 3000;

    /**
     * Timer service. (injected by a setter method)
     */
    private TimerService timerService;

    /**
     * Local method that is used by the other bean in order to start a timer on this bean.
     */
    public void startTimer() {
        Date expiration = new Date(System.currentTimeMillis() + FIRING_TIME);
        timerService.createTimer(expiration, "Timer on TimedBean object");
    }

    /**
     * Invoked by the EJB container upon timer expiration.
     * @param timer timer whose expiration caused this notification.
     */
    public void ejbTimeout(final Timer timer) {
        System.out.println(" TimedBean -> Got a timer with value '" + timer + "'.");
    }

    /**
     * Use a setter method to inject the timer service.
     * @param timerService the instance of the timer service.
     */
    @Resource
    public void setTimerService(final TimerService timerService) {
        this.timerService = timerService;
    }
}
